@@ -13,10 +13,12 @@ from .base import ServiceComponent
 from .files import DraftFilesComponent
 from .metadata import DraftMetadataComponent
 from .pid import PIDComponent
+from .relations import RelationsComponent
 
 __all__ = (
     'ServiceComponent',
     'DraftFilesComponent',
     'DraftMetadataComponent',
     'PIDComponent',
+    'RelationsComponent',
 )
